==> webkit2gtk_2.46.0.orig.tar.xz: webkitgtk-2.46.0/Source/WebCore/dom/WritingSuggestionData.h <==
/*
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/text/WTFString.h>

namespace WebCore {

class WritingSuggestionData {
    WTF_MAKE_FAST_ALLOCATED;
public:
    WritingSuggestionData(String&& content, String&& currentText, uint64_t&& offset, String&& originalPrefix, String&& originalSuffix, bool supportsSuffix)
        : m_content(WTFMove(content))
        , m_currentText(WTFMove(currentText))
        , m_originalPrefix(WTFMove(originalPrefix))
        , m_originalSuffix(WTFMove(originalSuffix))
        , m_offset(WTFMove(offset))
        , m_supportsSuffix(supportsSuffix)
    {
        ASSERT(!m_content.isEmpty());
    }

    String content() const { return m_content; }

    String currentText() const { return m_currentText; }

    uint64_t offset() const { return m_offset; }

    String originalPrefix() const { return m_originalPrefix; }

    String originalSuffix() const { return m_originalSuffix; }

    bool supportsSuffix() const { return m_supportsSuffix; }

private:
    String m_content;
    String m_currentText;

    String m_originalPrefix;
    String m_originalSuffix;

    uint64_t m_offset { 0 };
    bool m_supportsSuffix { false };
};

}

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebCore/dom/WritingSuggestionData.h <==
/*
 * Copyright (C) 2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/text/WTFString.h>

namespace WebCore {

class WritingSuggestionData {
    WTF_MAKE_TZONE_ALLOCATED(WritingSuggestionData);
public:
    WritingSuggestionData(String&& content, String&& currentText, uint64_t&& offset, String&& originalPrefix, String&& originalSuffix, bool supportsSuffix)
        : m_content(WTF::move(content))
        , m_currentText(WTF::move(currentText))
        , m_originalPrefix(WTF::move(originalPrefix))
        , m_originalSuffix(WTF::move(originalSuffix))
        , m_offset(WTF::move(offset))
        , m_supportsSuffix(supportsSuffix)
    {
        ASSERT(!m_content.isEmpty());
    }

    String content() const { return m_content; }

    String currentText() const { return m_currentText; }

    uint64_t offset() const { return m_offset; }

    String originalPrefix() const { return m_originalPrefix; }

    String originalSuffix() const { return m_originalSuffix; }

    bool supportsSuffix() const { return m_supportsSuffix; }

private:
    String m_content;
    String m_currentText;

    String m_originalPrefix;
    String m_originalSuffix;

    uint64_t m_offset { 0 };
    bool m_supportsSuffix { false };
};

} // namespace WebCore
